@@ -5,12 +5,12 @@ const QString iconSilent = "/usr/share/icons/hicolor/48x48/hildon/statusarea_sil
 const QString iconGeneral = "/usr/share/icons/hicolor/48x48/hildon/statusarea_volumelevel4.png";
 
 ProfileChangerWidget::ProfileChangerWidget(QWidget *parent) :
-    QMainWindow(parent),
+    QWidget(parent),
     ui(new Ui::ProfileChangerWidget)
 {
     syslog(LOG_WARNING, "profile-changer-widget.cpp setupui");
     ui->setupUi(this);
-    setAttribute(Qt::WA_TranslucentBackground);
+    this->setAttribute(Qt::WA_TranslucentBackground);
     if (!QSettings().contains("profilechangerwidget/width"))
         QSettings().setValue("profilechangerwidget/width", 48);
     if (!QSettings().contains("profilechangerwidget/height"))
